import { ConnectionManager } from 'typeorm';
import { Container } from 'typedi';
/**
 * Allows to inject an Connection using typedi's Container.
 */
export function InjectConnection(connectionName) {
    if (connectionName === void 0) { connectionName = 'default'; }
    return function (object, propertyName, index) {
        Container.registerHandler({
            object: object,
            index: index,
            propertyName: propertyName,
            value: function () {
                var connectionManager = Container.get(ConnectionManager);
                if (!connectionManager.has(connectionName))
                    throw new Error("Cannot get connection \"" + connectionName + "\" from the connection manager. " +
                        "Make sure you have created such connection. Also make sure you have called useContainer(Container) " +
                        "in your application before you established a connection and importing any entity.");
                return connectionManager.get(connectionName);
            },
        });
    };
}
//# sourceMappingURL=InjectConnection.js.map