import { ConnectionManager } from 'typeorm';
import { Container } from 'typedi';
/**
 * Allows to inject an EntityManager using typedi's Container.
 */
export function InjectManager(connectionName) {
    if (connectionName === void 0) { connectionName = 'default'; }
    return function (object, propertyName, index) {
        Container.registerHandler({
            object: object,
            index: index,
            propertyName: propertyName,
            value: function () {
                var connectionManager = Container.get(ConnectionManager);
                if (!connectionManager.has(connectionName))
                    throw new Error("Cannot get connection \"" + connectionName + "\" from the connection manager. " +
                        "Make sure you have created such connection. Also make sure you have called useContainer(Container) " +
                        "in your application before you established a connection and importing any entity.");
                var connection = connectionManager.get(connectionName);
                var entityManager = connection.manager;
                if (!entityManager)
                    throw new Error("Entity manager was not found on \"" + connectionName + "\" connection. " +
                        "Make sure you correctly setup connection and container usage.");
                return entityManager;
            },
        });
    };
}
//# sourceMappingURL=InjectManager.js.map